@@ -1,15 +1,14 @@
-#!/bin/bash
+#!/bin/bash -e
 
 if [ -z "$SAMBA_GIT_URL" ]; then
 	SAMBA_GIT_URL=git://git.samba.org/samba.git
 fi
 
 LDBTMP=`mktemp -d`
-git clone --depth 1 $SAMBA_GIT_URL $LDBTMP
-if [ ! -z "$REFSPEC" ]; then
-	pushd $LDBTMP
-	git checkout $REFSPEC || exit 1
-	popd
+if [ -d $SAMBA_GIT_URL/.bzr ]; then
+	bzr co --lightweight $SAMBA_GIT_URL $LDBTMP
+else
+	git clone --depth 1 $SAMBA_GIT_URL $LDBTMP
 fi
 pushd $LDBTMP/source4/lib/ldb
 ./configure
